searchData={"items":[{"type":"module","title":"DomHelpers","doc":"Just `use DomHelpers` to import all the methods.\n\nFor more information about accessor helpers, see `DomHelpers.Accessors`.\n\nFor more information about selection helpers, see `DomHelpers.Selectors`.","ref":"DomHelpers.html"},{"type":"module","title":"DomHelpers.Accessors","doc":"Collection of methods to simplify the access to different parts of the DOM.","ref":"DomHelpers.Accessors.html"},{"type":"function","title":"DomHelpers.Accessors.attribute/2","doc":"Retrieve the values of the given attribute in the given fragment.","ref":"DomHelpers.Accessors.html#attribute/2"},{"type":"function","title":"Examples - DomHelpers.Accessors.attribute/2","doc":"```\niex> find(~s(  First  Second  Third  ), \"li\") |> attribute(\"class\")\n~w(odd even odd)\n\niex> find(~s(  First  Second  Third  ), \"li\") |> attribute(\"data-test\")\n~w(first second third)\n\niex> find(~s(  First  Second  Third  ), \".even\") |> attribute(\"data-test\")\n~w(second)","ref":"DomHelpers.Accessors.html#attribute/2-examples"},{"type":"function","title":"DomHelpers.Accessors.attribute/3","doc":"Behaves like `attribute/2` but uses the second argument as selector.","ref":"DomHelpers.Accessors.html#attribute/3"},{"type":"function","title":"Examples - DomHelpers.Accessors.attribute/3","doc":"```\niex> attribute(~s(  First  Second  Third  ), \"li\", \"class\")\n~w(odd even odd)\n\niex> attribute(~s(  First  Second  Third  ), \"li\", \"data-test\")\n~w(first second third)\n\niex> attribute(~s(  First  Second  Third  ), \".even\", \"data-test\")\n~w(second)\n```","ref":"DomHelpers.Accessors.html#attribute/3-examples"},{"type":"function","title":"DomHelpers.Accessors.find/2","doc":"Finds all the nodes in the htmlable that satisfy the selector.","ref":"DomHelpers.Accessors.html#find/2"},{"type":"function","title":"Examples - DomHelpers.Accessors.find/2","doc":"```\niex> find(~s(  First  Second  Third  ), \".odd\")\n[{\"li\", [{\"class\", \"odd\"}], [\"First\"]}, {\"li\", [{\"class\", \"odd\"}], [\"Third\"]}]\n\niex> find(~s(  First  Second  Third  ), \".even\")\n[{\"li\", [{\"class\", \"even\"}], [\"Second\"]}]\n\niex> find(~s(  First  Second  Third  ), \".none\")\n[]\n\niex> find(~s(  First  Second  Third  ), \"li\")\n[{\"li\", [{\"class\", \"odd\"}], [\"First\"]}, {\"li\", [{\"class\", \"even\"}], [\"Second\"]}, {\"li\", [{\"class\", \"odd\"}], [\"Third\"]}]\n```","ref":"DomHelpers.Accessors.html#find/2-examples"},{"type":"function","title":"DomHelpers.Accessors.find_count/2","doc":"Returns the number of elements that satisfy the given selector.","ref":"DomHelpers.Accessors.html#find_count/2"},{"type":"function","title":"Examples - DomHelpers.Accessors.find_count/2","doc":"```\niex> find_count(~s(  First  Second  Third  ), \".odd\")\n2\n\niex> find_count(~s(  First  Second  Third  ), \".even\")\n1\n\niex> find_count(~s(  First  Second  Third  ), \".none\")\n0\n\niex> find_count(~s(  First  Second  Third  ), \"li\")\n3\n```","ref":"DomHelpers.Accessors.html#find_count/2-examples"},{"type":"function","title":"DomHelpers.Accessors.find_first/2","doc":"Like `find/2` but gets the first instance.","ref":"DomHelpers.Accessors.html#find_first/2"},{"type":"function","title":"Examples - DomHelpers.Accessors.find_first/2","doc":"```\niex> find_first(~s(  First  Second  Third  ), \".odd\")\n{\"li\", [{\"class\", \"odd\"}], [\"First\"]}\n\niex> find_first(~s(  First  Second  Third  ), \".even\")\n{\"li\", [{\"class\", \"even\"}], [\"Second\"]}\n\niex> find_first(~s(  First  Second  Third  ), \".none\")\nnil\n\niex> find_first(~s(  First  Second  Third  ), \"li\")\n{\"li\", [{\"class\", \"odd\"}], [\"First\"]}\n```","ref":"DomHelpers.Accessors.html#find_first/2-examples"},{"type":"function","title":"DomHelpers.Accessors.text/3","doc":"Returns the whole text inside the html fragment passed in. Spaces are normalised (meaning that if there are multiple\nspaces together they are reduced to just one and the text is trimmed on both ends).\n\nFirst arguments is an htmlable (see `DomHelpers.Htmlable`), second can either be a selector or options. If a selector\nis passed in, `find/2` will be used to locate matching elements before getting the text. In case a selector is given,\na third optional argument with options can be passed in.\n\nOptions to `Floki.text/2` can be passed inside the `:text` key in the options.","ref":"DomHelpers.Accessors.html#text/3"},{"type":"function","title":"Examples - DomHelpers.Accessors.text/3","doc":"```\niex> text(~s(   First     Second     Third   ), \".odd\")\n\"First Third\"\n\niex> text(~s(   First     Second     Third   ), \".even\")\n\"Second\"\n\niex> text(~s(   First     Second     Third   ), \".none\")\n\"\"\n\niex> text(~s(   First     Second     Third   ), \"li\")\n\"First Second Third\"\n\niex> find(~s(   First     Second     Third   ), \"li\") |> Enum.map(&text/1)\n~w(First Second Third)\n```","ref":"DomHelpers.Accessors.html#text/3-examples"},{"type":"protocol","title":"DomHelpers.Htmlable","doc":"Implements conversion from anything to something Floki can parse.","ref":"DomHelpers.Htmlable.html"},{"type":"function","title":"DomHelpers.Htmlable.to_html/1","doc":"Convert the given input to a parseable HTML fragment.","ref":"DomHelpers.Htmlable.html#to_html/1"},{"type":"type","title":"DomHelpers.Htmlable.t/0","doc":"All the types that implement this protocol.","ref":"DomHelpers.Htmlable.html#t:t/0"},{"type":"module","title":"DomHelpers.Selectors","doc":"Collection of methods to simplify the creation of complex selectors.","ref":"DomHelpers.Selectors.html"},{"type":"function","title":"DomHelpers.Selectors.with_attr/2","doc":"Complements the selector by checking that the attribute is present.","ref":"DomHelpers.Selectors.html#with_attr/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_attr/2","doc":"```\niex> with_attr(\"input\", \"checked\")\n~s/input[\"checked\"]/\n```","ref":"DomHelpers.Selectors.html#with_attr/2-examples"},{"type":"function","title":"DomHelpers.Selectors.with_attr/3","doc":"Complements the selector by checking that the attribute has the given value.\n\nValue can either be a value or a tuple `{matcher_name, value}` where `matcher_name`\ncan be one of:\n\n- `:contains_word` for `~=`.\n- `:contains` for `*=`.\n- `:equal` for `=`.\n- `:ends_with` for `$=`.\n- `:starts_with` for `^=`.\n- `:subcode` for `|=`.\n\nFor more information on these selectors, please check [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/Attribute_selectors).","ref":"DomHelpers.Selectors.html#with_attr/3"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_attr/3","doc":"```\niex> with_attr(\"input\", \"type\", \"text\")\n~s/input[\"type\"=\"text\"]/\n\niex> with_attr(\"input\", \"class\", {:contains_word, \"hidden\"})\n~s/input[\"class\"~=\"hidden\"]/\n\niex> with_attr(\"input\", \"type\", {:equal, \"text\"})\n~s/input[\"type\"=\"text\"]/\n\niex> with_attr(\"div\", \"data-test\", {:ends_with, \"editor\"})\n~s/div[\"data-test\"$=\"editor\"]/\n\niex> with_attr(\"div\", \"data-test\", {:starts_with, \"editor\"})\n~s/div[\"data-test\"^=\"editor\"]/\n\niex> with_attr(\"main\", \"lang\", {:subcode, \"es\"})\n~s/main[\"lang\"|=\"es\"]/\n```","ref":"DomHelpers.Selectors.html#with_attr/3-examples"},{"type":"function","title":"DomHelpers.Selectors.with_attrs/2","doc":"Like `with_attr/2` but several attributes can be passed at once.\n\nAttributes can be passed as a map or keywords. In both cases, keys are the names\nof the attributes, while the keys can be:\n\n- `true` for just checking that the attribute is present.\n- `false` for checking that the attribute is not present.\n- Any other value would be passed directly as attribute value to `with_attr/3`. Check\n  its documentation for all the options.","ref":"DomHelpers.Selectors.html#with_attrs/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_attrs/2","doc":"```\niex> with_attrs(\"input\", type: \"checkbox\", checked: true)\n~s/input[\"type\"=\"checkbox\"][\"checked\"]/\n\niex> with_attrs(\"input\", name: false, class: {:contains_word, \"hola\"}, \"data-test\": false)\n~s/input[\"class\"~=\"hola\"]:not([\"name\"]):not([\"data-test\"])/\n```","ref":"DomHelpers.Selectors.html#with_attrs/2-examples"},{"type":"function","title":"DomHelpers.Selectors.with_class/2","doc":"Add the class selector to the given one.","ref":"DomHelpers.Selectors.html#with_class/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_class/2","doc":"```\niex> with_class(\"div\", \"hidden\")\n\"div.hidden\"\n\niex> with_class(\"span\", \"flex\")\n\"span.flex\"\n```","ref":"DomHelpers.Selectors.html#with_class/2-examples"},{"type":"function","title":"DomHelpers.Selectors.with_classes/2","doc":"Checks if the selector contains the given classes.","ref":"DomHelpers.Selectors.html#with_classes/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_classes/2","doc":"```\niex> with_classes(\"div\", ~w(flex mb-4))\n\"div.flex.mb-4\"\n\niex> with_classes(\"span\", ~w(p-1 m-2))\n\"span.p-1.m-2\"\n```","ref":"DomHelpers.Selectors.html#with_classes/2-examples"},{"type":"function","title":"DomHelpers.Selectors.with_id/2","doc":"Adds the given id to the selector passed in.","ref":"DomHelpers.Selectors.html#with_id/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.with_id/2","doc":"```\niex> with_id(\"main\", \"main_content\")\n\"main#main_content\"\n\niex> with_id(\"div\", \"modal\")\n\"div#modal\"\n```","ref":"DomHelpers.Selectors.html#with_id/2-examples"},{"type":"function","title":"DomHelpers.Selectors.without_attr/2","doc":"Complements the selector by checking that it does not have the given attribute.","ref":"DomHelpers.Selectors.html#without_attr/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.without_attr/2","doc":"```\niex> without_attr(\"input\", \"checked\")\n~s/input:not([\"checked\"])/\n```","ref":"DomHelpers.Selectors.html#without_attr/2-examples"},{"type":"function","title":"DomHelpers.Selectors.without_attr/3","doc":"Complements the selector by checking that it does not have the given attribute with the\ngiven value. Check `with_attr/3` for possible values.","ref":"DomHelpers.Selectors.html#without_attr/3"},{"type":"function","title":"Examples - DomHelpers.Selectors.without_attr/3","doc":"```\niex> without_attr(\"input\", \"type\", \"text\")\n~s/input:not([\"type\"=\"text\"])/\n\niex> without_attr(\"input\", \"class\", {:contains_word, \"hidden\"})\n~s/input:not([\"class\"~=\"hidden\"])/\n\niex> without_attr(\"input\", \"type\", {:equal, \"text\"})\n~s/input:not([\"type\"=\"text\"])/\n\niex> without_attr(\"div\", \"data-test\", {:ends_with, \"editor\"})\n~s/div:not([\"data-test\"$=\"editor\"])/\n\niex> without_attr(\"div\", \"data-test\", {:starts_with, \"editor\"})\n~s/div:not([\"data-test\"^=\"editor\"])/\n\niex> without_attr(\"main\", \"lang\", {:subcode, \"es\"})\n~s/main:not([\"lang\"|=\"es\"])/\n```","ref":"DomHelpers.Selectors.html#without_attr/3-examples"},{"type":"function","title":"DomHelpers.Selectors.without_class/2","doc":"Modifies the selector to check it does not have the given class.","ref":"DomHelpers.Selectors.html#without_class/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.without_class/2","doc":"```\niex> without_class(\"div\", \"hidden\")\n~s/div:not(.hidden)/\n```","ref":"DomHelpers.Selectors.html#without_class/2-examples"},{"type":"function","title":"DomHelpers.Selectors.without_classes/2","doc":"Modifies the selector to check it does not contain the given classes.","ref":"DomHelpers.Selectors.html#without_classes/2"},{"type":"function","title":"Examples - DomHelpers.Selectors.without_classes/2","doc":"```\niex> without_classes(\"div\", ~w(flex mb-4))\n~s/div:not(.flex):not(.mb-4)/\n```","ref":"DomHelpers.Selectors.html#without_classes/2-examples"}],"content_type":"text/markdown"}